@@ -1,5 +1,6 @@
 """Parse DCTAP/CSV, return two-item tuple: (list of shape objects, list of warnings)."""
 
+import re
 from collections import defaultdict
 from csv import DictReader
 from io import StringIO as StringBuffer
@@ -15,9 +16,34 @@ def csvreader(open_csvfile_obj, config_dict):
     (csvrows, csvwarns) = _get_rows(open_csvfile_obj, config_dict)
     (tapshapes, tapwarns) = _get_tapshapes(csvrows, config_dict)
     tapwarns = {**csvwarns, **tapwarns}
+    tapshapes = _add_namespaces(tapshapes, config_dict, csvrows)
     return (tapshapes, tapwarns)
 
 
+def _add_namespaces(tapshapes=None, config_dict=None, csvrows=None):
+    """@@@"""
+    prefixes_used = _get_prefixes_actually_used(csvrows)
+    tapshapes['namespaces'] = {}
+    if config_dict.get('prefixes'):
+        for prefix in prefixes_used:
+            if config_dict['prefixes'].get(prefix):
+                tapshapes['namespaces'][prefix] = config_dict['prefixes'].get(prefix)
+
+    return tapshapes
+
+
+def _get_prefixes_actually_used(csvrows):
+    """@@@"""
+    prefixes = set()
+    for row in csvrows:
+        for element in ['propertyID', 'valueDataType', 'shapeID', 'valueShape']:
+            if row.get(element):
+                pre = re.match(r"(.*:)", row.get(element))
+                if pre:
+                    prefixes.add(pre.group(0))
+    return prefixes
+
+
 def _get_rows(open_csvfile_obj, config_dict):
     """Extract from _io.TextIOWrapper object a list of CSV file rows as dicts."""
     # pylint: disable=too-many-locals
@@ -25,7 +51,6 @@ def _get_rows(open_csvfile_obj, config_dict):
     csvfile_contents_str = open_csvfile_obj.read()
     tmp_buffer = StringBuffer(csvfile_contents_str)
     csvlines_stripped = [line.strip() for line in tmp_buffer]
-    # breakpoint(context=5)
     raw_header_line_list = csvlines_stripped[0].split(",")
     new_header_line_list = []
 
@@ -42,7 +67,6 @@ def _get_rows(open_csvfile_obj, config_dict):
             config_dict["element_aliases"][element.lower()] = element
     recognized_elements = [elem.lower() for elem in recognized_elements]
 
-    # breakpoint(context=5)
     for column in raw_header_line_list:
         column = coerce_concise(column)
         column = _normalize_element_name(column, config_dict.get("element_aliases"))
