@@ -46,7 +46,7 @@ class TAPStatementTemplate:
         self._valueDataType_warn_if_valueNodeType_literal_used_with_any_valueShape()
         self._valueConstraintType_picklist_parse(settings)
         self._valueNodeType_is_from_enumerated_list(settings)
-        self._parse_elements_configured_as_list_elements(settings)
+        self._parse_elements_configured_as_picklist_elements(settings)
         return self
 
     def _warn_if_propertyID_not_IRIlike(self):
@@ -120,7 +120,7 @@ class TAPStatementTemplate:
         """valueConstraintType minLength: coerce integer (or return string)."""
         self.valueConstraintType = self.valueConstraintType.lower()
         value_constraint = self.valueConstraint
-        if self.valueConstraintType in ('minlength', 'maxlength'):
+        if self.valueConstraintType in ("minlength", "maxlength"):
             if value_constraint:
                 self.valueConstraint = coerce_integer(value_constraint)
         return self
@@ -128,7 +128,7 @@ class TAPStatementTemplate:
     def _valueConstraintType_minmaxlength_warn_if_not_integer(self):
         """Warns if valueConstraint minLength not a nonnegative integer."""
         self.valueConstraintType = self.valueConstraintType.lower()
-        if self.valueConstraintType in ('minlength', 'maxlength'):
+        if self.valueConstraintType in ("minlength", "maxlength"):
             try:
                 int(self.valueConstraint)
             except (ValueError, TypeError):
@@ -158,9 +158,9 @@ class TAPStatementTemplate:
                 float(self.valueConstraint)
             except (ValueError, TypeError):
                 self.state_warns["valueConstraint"] = (
-                        f"Value constraint type is {repr(self.valueConstraintType)}, "
-                        f"but {repr(self.valueConstraint)} is not numeric."
-                    )
+                    f"Value constraint type is {repr(self.valueConstraintType)}, "
+                    f"but {repr(self.valueConstraint)} is not numeric."
+                )
         return self
 
     def _valueConstraintType_pattern_warn_if_valueConstraint_not_valid_regex(self):
@@ -190,7 +190,7 @@ class TAPStatementTemplate:
     def _valueConstraintType_languageTag_parse(self, settings):
         """For valueConstraintType languageTag, splits valueConstraint on whitespace."""
         self.valueConstraintType = self.valueConstraintType.lower()
-        sep = settings.get("list_item_separator", " ")
+        sep = settings.get("picklist_item_separator", " ")
         if self.valueConstraintType == "languagetag":
             if self.valueConstraint:
                 self.valueConstraint = self.valueConstraint.split(sep)
@@ -211,7 +211,7 @@ class TAPStatementTemplate:
     def _valueConstraintType_picklist_parse(self, settings):
         """If valueConstraintType is Picklist, split valueConstraint on whitespace."""
         self.valueConstraintType = self.valueConstraintType.lower()
-        sep = settings.get("list_item_separator", " ")
+        sep = settings.get("picklist_item_separator", " ")
         if self.valueConstraintType == "picklist":
             if self.valueConstraint:
                 self.valueConstraint = self.valueConstraint.split(sep)
@@ -260,19 +260,21 @@ class TAPStatementTemplate:
                     f"so node type should not be {repr(self.valueNodeType)}."
                 )
 
-    def _parse_elements_configured_as_list_elements(self, settings):
+    def _parse_elements_configured_as_picklist_elements(self, settings):
         """Parse elements configured as list elementss."""
-        if settings.get("list_item_separator"):
-            separator = settings.get("list_item_separator")
+        if settings.get("picklist_item_separator"):
+            separator = settings.get("picklist_item_separator")
         else:
             separator = " "
 
         if settings.get("list_elements"):
-            list_elements = settings.get("list_elements")
+            picklist_elements = settings.get("list_elements")
+        elif settings.get("picklist_elements"):
+            picklist_elements = settings.get("picklist_elements")
         else:
-            list_elements = []
+            picklist_elements = []
 
-        for element in list_elements:
+        for element in picklist_elements:
             if getattr(self, element):
                 setattr(self, element, getattr(self, element).split(separator))
 
